@@ -14,7 +14,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import urllib
+from six.moves import urllib
 
 from keystoneclient import base
 
@@ -86,9 +86,8 @@ class UserManager(base.ManagerWithFind):
         return self._update("/users/%s/OS-KSADM/tenant" % base.getid(user),
                             params, "user")
 
-    def create(self, name, password, email, tenant_id=None, enabled=True):
+    def create(self, name, password, email=None, tenant_id=None, enabled=True):
         """Create a user."""
-        # FIXME(ja): email should be optional, keystone currently requires it
         params = {"user": {"name": name,
                            "password": password,
                            "tenantId": tenant_id,
@@ -114,7 +113,7 @@ class UserManager(base.ManagerWithFind):
 
         query = ""
         if params:
-            query = "?" + urllib.urlencode(params)
+            query = "?" + urllib.parse.urlencode(params)
 
         if not tenant_id:
             return self._list("/users%s" % query, "users")
